@@ -1,6 +1,6 @@
 ################################################################################
 ##
-## $Id: portfolio.calcShares.test.R 411 2007-04-22 19:29:16Z enos $
+## $Id: portfolio.calcShares.test.R 1625 2010-02-18 19:44:29Z enos $
 ##
 ## Tests "calcShares" method of "portfolio"
 ##
@@ -37,7 +37,7 @@ trial.0 <- try(
                )
 
 if(class(trial.0) == "try-error"){
-  stopifnot(as.logical(grep("Error*valid.price\.var!", trial.0[1])))
+  stopifnot(isTRUE(as.logical(grep("Error.*valid price\\.var!", trial.0[1]))))
 }
 
 ## Corner Case: shares slot has 0 rows
